@@ -19,7 +19,15 @@ logging.basicConfig(level=logging.INFO)
 
 
 class TickerDax:
-    def __init__(self, email=None, rest_api_key=None, websocket_api_key=None, fast_start=True, connect=True):
+    def __init__(
+            self,
+            email=None,
+            rest_api_key=None,
+            websocket_api_key=None,
+            fast_start=True,
+            connect=True,
+            log_connection=True
+    ):
         websocket_api_prefix = 'ws'
         rest_api_prefix = 'api'
         if os.environ.get(Envs.DEV):
@@ -33,6 +41,7 @@ class TickerDax:
         self.missing_values = []
         self._batch_size = 100
         self._fast_start = fast_start
+        self._log_connection = log_connection
 
         # rest api configuration
         self._rest_api_host = f'https://{rest_api_prefix}.{NAME}.com'
@@ -142,7 +151,8 @@ class TickerDax:
                 db=0
             )
             self._redis_client.ping()
-            self._logger.info(f'Redis server is connected!')
+            if self._log_connection:
+                self._logger.info(f'Redis server is connected!')
             return True
         except redis.exceptions.ConnectionError:
             return False
@@ -258,13 +268,16 @@ class TickerDax:
             ) as connected_socket:
                 self._logger.info(f"> Connected to {uri}")
                 while True:
-                    data = json.loads(await connected_socket.recv())
-                    symbol = data.get('symbol')
-                    timestamp = data.get('id')
-                    if symbol and timestamp:
-                        for key in self._get_cache_keys(client._format_route(route), [symbol], [timestamp]):
-                            self._redis_client.set(key, json.dumps(data))
-                            self._logger.info(f'Cached: {pformat(data)}')
+                    try:
+                        data = json.loads(await connected_socket.recv())
+                        symbol = data.get('symbol')
+                        timestamp = data.get('id')
+                        if symbol and timestamp:
+                            for key in self._get_cache_keys(self._format_route(route), [symbol], [timestamp]):
+                                self._redis_client.set(key, json.dumps(data))
+                                self._logger.info(f'Cached: {pformat(data)}')
+                    except Exception as error:
+                        self._logger.error(error)
 
         except InvalidStatusCode as error:
             if error.status_code == 401:
