@@ -25,9 +25,13 @@ class Streamer(ConfigBase):
         """
         routes = self._config.get('routes', {})
         if routes:
-            # unless told not to, first backwards fill the history from the start date in the config
-            if self._config.get('back_fill', True):
-                Downloader(config=self._config_file_path, till_now=True)
+            # unless told not to, fill the history from the start date in the config till now
+            if self._config.get('fill_to_now', True):
+                Downloader(
+                    config=self._config_file_path,
+                    client_kwargs={'log_connection': False},
+                    till_now=True
+                )
 
             # stream updates to the cache indefinitely
             self._logger.info(f'Starting streams...')
